summaryrefslogtreecommitdiff
path: root/src/formats/osml/OsmlParser.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/formats/osml/OsmlParser.hpp')
-rw-r--r--src/formats/osml/OsmlParser.hpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/formats/osml/OsmlParser.hpp b/src/formats/osml/OsmlParser.hpp
index 37505b4..f8f5b6c 100644
--- a/src/formats/osml/OsmlParser.hpp
+++ b/src/formats/osml/OsmlParser.hpp
@@ -17,32 +17,32 @@
*/
/**
- * @file OsdmParser.hpp
+ * @file OsmlParser.hpp
*
* Contains the parser of the osdm format, the standard plain-text format used
* by Ousía for documents.
*
* @author Andreas Stöckel (astoecke@techfak.uni-bielefeld.de)
*/
-#ifndef _OUSIA_OSDM_PARSER_HPP_
-#define _OUSIA_OSDM_PARSER_HPP_
+#ifndef _OUSIA_OSML_PARSER_HPP_
+#define _OUSIA_OSML_PARSER_HPP_
#include <core/parser/Parser.hpp>
namespace ousia {
/**
* OsdmParser is a small wrapper implementing the Parser interface. The actual
* parsing is performed with the OsdmStreamParser in conjunction with the
* ParserStateStack.
*/
-class OsdmParser : public Parser {
+class OsmlParser : public Parser {
protected:
void doParse(CharReader &reader, ParserContext &ctx) override;
};
}
-#endif /* _OUSIA_OSDM_PARSER_HPP_ */
+#endif /* _OUSIA_OSML_PARSER_HPP_ */
@@ -17,32 +17,32 @@
*
- * Contains the parser of the osdm format, the standard plain-text format used
+ * Contains the parser of the Osml format, the standard plain-text format used
* by Ousía for documents.
*
@@ -17,32 +17,32 @@
namespace ousia {
/**
- * OsdmParser is a small wrapper implementing the Parser interface. The actual
- * parsing is performed with the OsdmStreamParser in conjunction with the
+ * OsmlParser is a small wrapper implementing the Parser interface. The actual
+ * parsing is performed with the OsmlStreamParser in conjunction with the
* ParserStateStack.
*/